==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/data_factory/form_factory/expand_select_forms/expand_multi_select_form.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import 'package:verttice_logic/verttice_logic.dart';

// 🌎 Project imports:
import 'package:verttice_ui/src/widgets/themed_widgets/themed_search_multi_list.dart';
import 'package:verttice_ui/verttice_ui.dart';
import 'expand_select_add_option.dart';

class ExpandMultiSelectFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final String optionsID;
  final List<String>? value;
  final FormFieldState<dynamic>? state;
  final List<String>? defaultOptions;

  final String? tip;

  const ExpandMultiSelectFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    required this.optionsID,
    this.defaultOptions,
    this.value,
    this.state,
    this.tip,
  }) : super(key: key);

  @override
  State<ExpandMultiSelectFormFactory> createState() =>
      _ExpandMultiSelectState();
}

class _ExpandMultiSelectState extends State<ExpandMultiSelectFormFactory> {
  List<String> _value = [];
  final String _loadKey = IDs.l16();

  @override
  void initState() {
    super.initState();
    if (mounted) {
      _value = DataClassUtils.dynamicToStringList(widget.value);
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant ExpandMultiSelectFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToStringList(widget.value);
    }
  }

  Future<void> _addOption({required List<String> currentOptions}) async {
    await sizedDialog(
      context: context,
      height: 400,
      width: 430,
      builder: (BuildContext context) {
        return ExpandSelectAddOption(
          displayName: widget.displayName,
          optionsID: widget.optionsID,
          currentOptions: currentOptions,
          onDone: () {
            Requery.queryCache.invalidateQueries(_loadKey);
          },
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      tip: widget.tip,
      child: SelectableText(_value.join(", ")),
      onPressed: () async {
        await sizedDialog(
          context: context,
          height: 400,
          width: 430,
          builder: (context) => Requery.query<List<String>>(
            key: _loadKey,
            future: () =>
                VertticeUIConfig.instance.expandableOptionsConfig.getOptions(
              optionsID: widget.optionsID,
            ),
            builder: ({
              required BuildContext context,
              required RequeryResponse<List<String>> response,
            }) {
              final options = [...?widget.defaultOptions, ...?response.data];

              if (response.loading) {
                return const ThemedMessage(
                  showLoading: true,
                );
              } else if (response.error != null) {
                return ThemedMessage(
                  message: "Failed to get options",
                  actions: [
                    ThemedIconButton(
                      onPressed: () {
                        Requery.queryCache.invalidateQueries(_loadKey);
                      },
                      icon: ThemedIcons.refresh(),
                    )
                  ],
                );
              } else if (options.isEmpty) {
                return ThemedMessage(
                  message: "No options yet",
                  actions: [
                    ThemedIconTextButton(
                      ThemedIcons.add(),
                      'Add Option',
                      onPressed: () async {
                        await _addOption(
                          currentOptions: [],
                        );
                      },
                    ),
                  ],
                );
              }
              return Scaffold(
                appBar: ThemedAppBar(
                  navigateBackButton: true,
                  title: "Select ${widget.displayName}",
                  actions: [
                    ThemedIconButton(
                      icon: ThemedIcons.add(),
                      onPressed: () async {
                        await _addOption(
                          currentOptions: options,
                        );
                      },
                    ),
                  ],
                ),
                body: Center(
                  child: Padding(
                    padding: const EdgeInsets.all(6),
                    child: SizedBox(
                      height: 590,
                      width: 350,
                      child: ThemedSearchMultiList<String>(
                        items: Set<String>.from(
                                options.map((e) => e.toLowerCase()).toList())
                            .toList()
                            .map((e) => e.titleCase)
                            .toList(),
                        selectedItems: _value,
                        selectedItemsCallback: (
                          List<String> data,
                        ) async {
                          widget.onChanged(widget.name, data);
                          widget.state?.didChange(data);
                          Navigator.pop(context);
                        },
                      ),
                    ),
                  ),
                ),
              );
            },
          ),
        );
      },
    );
  }
}

==> verttice_ui-0.1.10.tar.gz: lib/src/widgets/data_factory/form_factory/expand_select_forms/expand_multi_select_form.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import 'package:verttice_logic/verttice_logic.dart';

// 🌎 Project imports:
import 'package:verttice_ui/src/widgets/themed_widgets/themed_search_multi_list.dart';
import 'package:verttice_ui/verttice_ui.dart';
import 'expand_select_add_option.dart';

class ExpandMultiSelectFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final String optionsID;
  final List<String>? value;
  final FormFieldState<dynamic>? state;
  final List<String>? defaultOptions;

  final String? tip;

  const ExpandMultiSelectFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    required this.optionsID,
    this.defaultOptions,
    this.value,
    this.state,
    this.tip,
  }) : super(key: key);

  @override
  State<ExpandMultiSelectFormFactory> createState() =>
      _ExpandMultiSelectState();
}

class _ExpandMultiSelectState extends State<ExpandMultiSelectFormFactory> {
  List<String> _value = [];
  final String _loadKey = IDs.l16();

  @override
  void initState() {
    super.initState();
    if (mounted) {
      _value = DataClassUtils.dynamicToStringList(widget.value);
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant ExpandMultiSelectFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToStringList(widget.value);
    }
  }

  Future<void> _addOption({required List<String> currentOptions}) async {
    await sizedDialog(
      context: context,
      height: 400,
      width: 430,
      builder: (BuildContext context) {
        return ExpandSelectAddOption(
          displayName: widget.displayName,
          optionsID: widget.optionsID,
          currentOptions: currentOptions,
          onDone: () {
            Requery.queryCache.invalidateQueries(_loadKey);
          },
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      tip: widget.tip,
      child: SelectableText(_value.join(", ")),
      onPressed: () async {
        await sizedDialog(
          context: context,
          height: 400,
          width: 430,
          builder: (context) => Requery.query<List<String>>(
            key: _loadKey,
            future: () =>
                VertticeUI.instance.expandableOptionsConfig.getOptions(
              optionsID: widget.optionsID,
            ),
            builder: ({
              required BuildContext context,
              required RequeryResponse<List<String>> response,
            }) {
              final options = [...?widget.defaultOptions, ...?response.data];

              if (response.loading) {
                return const ThemedMessage(
                  showLoading: true,
                );
              } else if (response.error != null) {
                return ThemedMessage(
                  message: "Failed to get options",
                  actions: [
                    ThemedIconButton(
                      onPressed: () {
                        Requery.queryCache.invalidateQueries(_loadKey);
                      },
                      icon: ThemedIcons.refresh(),
                    )
                  ],
                );
              } else if (options.isEmpty) {
                return ThemedMessage(
                  message: "No options yet",
                  actions: [
                    ThemedIconTextButton(
                      ThemedIcons.add(),
                      'Add Option',
                      onPressed: () async {
                        await _addOption(
                          currentOptions: [],
                        );
                      },
                    ),
                  ],
                );
              }
              return Scaffold(
                appBar: ThemedAppBar(
                  navigateBackButton: true,
                  title: "Select ${widget.displayName}",
                  actions: [
                    ThemedIconButton(
                      icon: ThemedIcons.add(),
                      onPressed: () async {
                        await _addOption(
                          currentOptions: options,
                        );
                      },
                    ),
                  ],
                ),
                body: Center(
                  child: Padding(
                    padding: const EdgeInsets.all(6),
                    child: SizedBox(
                      height: 590,
                      width: 350,
                      child: ThemedSearchMultiList<String>(
                        items: Set<String>.from(
                                options.map((e) => e.toLowerCase()).toList())
                            .toList()
                            .map((e) => e.titleCase)
                            .toList(),
                        selectedItems: _value,
                        selectedItemsCallback: (
                          List<String> data,
                        ) async {
                          widget.onChanged(widget.name, data);
                          widget.state?.didChange(data);
                          Navigator.pop(context);
                        },
                      ),
                    ),
                  ),
                ),
              );
            },
          ),
        );
      },
    );
  }
}
